### Name: smoothSurvReg
### Title: Regression for a Survival Model with Smoothed Error Distribution
### Aliases: smoothSurvReg
### Keywords: survival smooth

### ** Examples

### We generate interval censored data and fit a model with few artificial covariates
x1 <- rbinom(50, 1, 0.4)                                         ## binary covariate
x2 <- rnorm(50, 180, 10)                                         ## continuous covariate
y1 <- 0.5*x1 - 0.01*x2 + 0.005 *x1*x2 + 1.5*rnorm(50, 0, 1)      ## generate log(T), left limit
t1 <- exp(y1)                                                    ## left limit of the survival time
t2 <- t1 + rgamma(50, 1, 1)                                      ## right limit of the survival time
surv <- Surv(t1, t2, type = "interval2")                         ## survival object

## Fit the model with an interaction
fit1 <- smoothSurvReg(surv ~ x1 * x2, info = FALSE, lambda = exp(2:(-1)))

## Print the summary information
summary(fit1, spline = TRUE)

## Plot the fitted error distribution
plot(fit1)

## Plot the fitted error distribution with its components
plot(fit1, components = TRUE)

## Plot the cumulative distribution function corresponding to the error density
survfit(fit1, cdf = TRUE)

## Plot survivor curves for persons with (x1, x2) = (0, 180) and (1, 180)
survfit(fit1, matrix(c(0, 1, 180, 180, 0, 180), ncol = 3))

## More involved examples can be found in script files
## used to perform analyses  and draw pictures 
## presented in /inst/doc/paper.pdf of this library.
## These script files together with data for Signal Tandmobiel
## example (section 6.1 of paper.pdf) can be obtained from
## arnost.komarek@med.kuleuven.ac.be



